import{f as u,a as h}from"../chunks/Ju_n_C2_.js";import{i as g}from"../chunks/Cv1GdJBR.js";import{w as l,x as v,y as d,z as x,A as a,B as e,C as _}from"../chunks/Dv3HkdC9.js";import{s as o}from"../chunks/JOtKPpyz.js";import{s as $,p}from"../chunks/C_HM03k2.js";const k={get error(){return p.error},get status(){return p.status}};$.updated.check;const m=k;var b=u("<h1> </h1> <p> </p>",1);function C(i,f){l(f,!1),g();var t=b(),r=v(t),n=a(r,!0);e(r);var s=_(r,2),c=a(s,!0);e(s),d(()=>{o(n,m.status),o(c,m.error?.message)}),h(i,t),x()}export{C as component};
