import{d as p,a as n,f as _}from"../chunks/Ju_n_C2_.js";import{a as u,L as y,ai as c,h as i,a4 as g,N as v,a6 as o,a8 as f,W as d,e as b,x as h,y as x}from"../chunks/Dv3HkdC9.js";import{s as E,a as O,l as T}from"../chunks/C6NEUSMl.js";function k(r,s){let t=null,l=i;var a;if(i){t=b;for(var e=g(document.head);e!==null&&(e.nodeType!==v||e.data!==r);)e=o(e);if(e===null)f(!1);else{var m=o(e);e.remove(),d(m)}}i||(a=document.head.appendChild(u()));try{y(()=>s(a),c)}finally{l&&(f(!0),d(t))}}const C=!0,M=!1,F=Object.freeze(Object.defineProperty({__proto__:null,prerender:C,ssr:M},Symbol.toStringTag,{value:"Module"}));var N=_('<link rel="icon" type="image/svg+xml"/>');function H(r,s){var t=p();k("12qhfyh",a=>{var e=N();x(()=>O(e,"href",T)),n(a,e)});var l=h(t);E(l,()=>s.children),n(r,t)}export{H as component,F as universal};
